=======
History
=======

v0.2.0
------

* Add ``Sentry`` : a falsey singleton for where none means something
* Add ``AncestorChainMap`` : a ``ChainMap`` with extra methods for insertion of parents and ancestors
* Improve formatting in docs.


0.1.2 (2019-12-31)
------------------

* Documentation upates to readme and contibution guidelines
* CI improvements


0.1.1 (2019-12-30)
------------------

* various minor fixes to get pypi deployment working.


0.1.0 (2019-12-30)
------------------

* ``UniqueTuple``
* benchmarking via pytest-benchmark
* ``AttyDict``
* ``ops``module w/ recursive gettattr and setattr functions.
